==> kubernetes-model-networking-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IPBlockFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface IPBlockFluent<A extends IPBlockFluent<A>> extends Fluent<A>{
  public String getCidr();
  public A withCidr(String cidr);
  public Boolean hasCidr();
  public A addToExcept(Integer index,String item);
  public A setToExcept(Integer index,String item);
  public A addToExcept(java.lang.String... items);
  public A addAllToExcept(Collection<String> items);
  public A removeFromExcept(java.lang.String... items);
  public A removeAllFromExcept(Collection<String> items);
  public List<String> getExcept();
  public String getExcept(Integer index);
  public String getFirstExcept();
  public String getLastExcept();
  public String getMatchingExcept(Predicate<String> predicate);
  public Boolean hasMatchingExcept(Predicate<String> predicate);
  public A withExcept(List<String> except);
  public A withExcept(java.lang.String... except);
  public Boolean hasExcept();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> kubernetes-model-networking-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IPBlockFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IPBlockFluent<A extends IPBlockFluent<A>> extends Fluent<A>{
  public String getCidr();
  public A withCidr(String cidr);
  public Boolean hasCidr();
  public A addToExcept(int index,String item);
  public A setToExcept(int index,String item);
  public A addToExcept(java.lang.String... items);
  public A addAllToExcept(Collection<String> items);
  public A removeFromExcept(java.lang.String... items);
  public A removeAllFromExcept(Collection<String> items);
  public List<String> getExcept();
  public String getExcept(int index);
  public String getFirstExcept();
  public String getLastExcept();
  public String getMatchingExcept(Predicate<String> predicate);
  public Boolean hasMatchingExcept(Predicate<String> predicate);
  public A withExcept(List<String> except);
  public A withExcept(java.lang.String... except);
  public Boolean hasExcept();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
